/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jsvg;

import com.jsevy.jxml.XMLElement;

/**
 * Class representing a font used in the document.
 * @author jsevy
 *
 */
class SVGFontFace extends XMLElement
{
    
    private String fontName;
    private String fontFamily;
    private String fontFamilyGeneric;
    private String fontPitch;
    
    
    public SVGFontFace(String fontName, String fontFamily, String fontFamilyGeneric, String fontPitch)
    {        
        this.fontName = fontName;
        this.fontFamily = fontFamily;
        this.fontFamilyGeneric = fontFamilyGeneric;
        this.fontPitch = fontPitch;
        
        populateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    private void populateXML()
    {
        this.setNodeName("font-face");
        
        this.setAttribute("name", fontName);
        this.setAttribute("font-family", fontFamily);
        this.setAttribute("font-family-generic", fontFamilyGeneric);
        this.setAttribute("font-pitch", fontPitch);
        
    }
}