/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jsvg;


import java.awt.geom.AffineTransform;




/**
 * Class representing a line segment.
 * @author jsevy
 *
 */
class SVGLine extends SVGEntity
{
    private RealPoint start, end;
    
    
    /**
     * Create a line segment between the specified endpoints.
     * 
     * @param start		One endpoint
     * @param end		The other endpoint
     * @param style         The ODGSTyle object specifying rendering parameters for the shape (color, thickness, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public SVGLine(RealPoint start, RealPoint end, SVGGraphicsStyle style, AffineTransform transform)
    {
        super(style, transform);
        
        this.start = start;
        this.end = end;
        
        populateXML();
    }
    
    
    /**
     * Create a line segment between the specified endpoints.
     * 
     * @param start     One endpoint
     * @param end       The other endpoint
     * @param style         The ODGSTyle object specifying rendering parameters for the shape (color, thickness, etc.)
     */
    public SVGLine(RealPoint start, RealPoint end, SVGGraphicsStyle style)
    {
        this(start, end, style, new AffineTransform());
    }
    
    
    
    /**
     * Populate XMLNode fields for XML generation
     */
    protected void populateXML()
    {
        this.setNodeName("line");
        
        // add attributes
        this.setAttribute("x1", scaleValue(start.x));
        this.setAttribute("y1", scaleValue(start.y));
        this.setAttribute("x2", scaleValue(end.x));
        this.setAttribute("y2", scaleValue(end.y));
        
        // add style attributes, and transform attribute if any
        super.populateXML();
        
        
        
    }
}