/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jsvg;


import java.awt.geom.AffineTransform;
import java.util.Vector;



/**
 * Class representing a set of line segments defining a closed polygon.
 * 
 * @author jsevy
 *
 */
class SVGPolygon extends SVGPolyline
{
        
    
    /**
     * Create a set of line segments that connects the specified points, including a segment from the last 
     * to the first if not already present.
     * 
     * @param vertices      The vertices
     * @param style         The ODGStyle object specifying rendering parameters for the shape (color, thickness, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public SVGPolygon(Vector<RealPoint> vertices, SVGGraphicsStyle style, AffineTransform transform)
    {
        super(vertices, style, transform);

        repopulateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    private void repopulateXML()
    {
        // just adjust name - all other parameters the same
        this.setNodeName("polygon");
    }
}