/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.jsvg;



import java.awt.geom.AffineTransform;




/**
 * Class representing a rectangle, with possibly curved corners.
 * @author jsevy
 *
 */
class SVGRectangle extends SVGEntity
{
    private double x, y;
    private double width, height;
    private double rx, ry;
    
    
    /**
     * 
     * @param x             Top left corner x coord
     * @param y             Top left corner y coord
     * @param width         Width of rectangle
     * @param height        Height of rectangle
     * @param rx            X radius of corners for rounded-corner rectangle; 0 gives standard rectangle
     * @param ry            Y radius of corners for rounded-corner rectangle; 0 gives standard rectangle
     * @param style         The ODGStyle object specifying rendering parameters for the shape (color, thickness, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public SVGRectangle(double x, double y, double width, double height, double rx, double ry, SVGGraphicsStyle style, AffineTransform transform)
    {
        super(style, transform);
        
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.style = style;
        this.rx = rx;
        this.ry = ry;
        
        populateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    protected void populateXML()
    {
        this.setNodeName("rect");
            
        // add attributes
        this.setAttribute("x", scaleValue(x));
        this.setAttribute("y", scaleValue(y));
        this.setAttribute("width", scaleValue(width));
        this.setAttribute("height", scaleValue(height));
        this.setAttribute("rx", scaleValue(rx));
        this.setAttribute("ry", scaleValue(ry));
        
        // add style attributes, and transform attribute if any
        super.populateXML();
        
    }
    
    
}