/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jsvg;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics2D;



/**
 * Class for style elements that apply to text rendering for things like font characteristics and color.
 * @author jsevy
 *
 */
class SVGTextStyle extends SVGStyle
{
    
    private Font font;
    private Color color;
    
    /**
     * Create a new text style.
     * @param graphics  The Java graphics object, used to extract font and color information
     */
    public SVGTextStyle(Graphics2D graphics)
    {
        // base class gets name
        
        this.font = graphics.getFont();
        this.color = graphics.getColor();
        
        populateXML();
    }
    
    
    
    /**
     * Used to determine if a given style is already in the global list of styles so that we
     * don't create redundant identical styles.
     */    
    public boolean equals(Object other)
    {
        if (other instanceof SVGTextStyle)
        {
            SVGTextStyle otherText = (SVGTextStyle)other;
            if ((font.equals(otherText.font)) && (color.equals(otherText.color)))
                return true;
            else
                return false;
        }
        else
            return false;
    }
    
    
    /**
     * Populate XMLNode fields for XML generation
     */
    private void populateXML()
    {
        // done by base class
        //this.setName("style");
        
        // add attributes
        
        //this.setAttribute("name", styleName));
        
        this.setAttribute("font-family", SVGFontFaces.mapJavaFontName(font.getName()));
        this.setAttribute("font-size", scaleValue(font.getSize()));
        this.setAttribute("fill", "#" + (Integer.toHexString(color.getRGB()).substring(2)));
        
        if (font.isBold())
            this.setAttribute("font-weight", "bold");
        
        if (font.isItalic())
            this.setAttribute("font-style", "italic");
        
    }
    
}
